@@ -13,8 +13,7 @@ import logging
 from pyaxiom import logger
 from pyaxiom.utils import urnify
 logger.level = logging.INFO
-logger.addHandler(logging.StreamHandler())
-
+logger.handlers = [logging.StreamHandler()]
 
 class TestTimeSeries(unittest.TestCase):
 
@@ -578,7 +577,6 @@ class TestTimeSeries(unittest.TestCase):
         assert nc is not None
 
         datavar = nc.variables.get('temperature')
-        logger.info(datavar.ncattrs())
         instrument_var_name = datavar.instrument
 
         instvar = nc.variables[instrument_var_name]
